@@ -12,32 +12,81 @@ class Planner(metaclass=ABCMeta):
 
     Args:
         robot (SingleArm or Bimanual): The manipulator robot type is SingleArm or Bimanual
-        self_collision_manager: CollisionManager for robot's self collision check
+        robot_col_manager: CollisionManager for robot's self collision check
         object_collision_manager: CollisionManager for collision check between robot and object
         dimension(int): robot arm's dof
     """
     def __init__(
         self,
         robot,
-        self_collision_manager,
-        object_collision_manager,
         dimension
     ):
         self.robot = robot
         self._dimension = dimension
-        if self_collision_manager is None:
-            logger.warning(f"This Planner does not do collision checking")
-            self.self_c_manager = None
-        else:
-            self.self_c_manager = self_collision_manager
-            check_collision = self.self_c_manager.in_collision_internal()
-            if check_collision:
-                raise CollisionError("Conflict confirmed. Check the joint settings again")
-        self.object_c_manager = object_collision_manager
+        
+        self.robot_col_mngr = None
+        self.object_col_mngr = None
+        self.is_attached = None
+        self.obj_info = None
+        self.T_between_grippper_and_obj = None
+        self.result_object_pose = None
 
     def __repr__(self) -> str:
         return 'pykin.planners.planner.{}()'.format(type(self).__name__)
 
+    def attach_object_on_robot(self):
+        self.robot_col_mngr.add_object(
+            self.obj_info["name"], 
+            gtype=self.obj_info["gtype"], 
+            gparam=self.obj_info["gparam"], 
+            transform=self.obj_info["transform"])
+        self.object_col_mngr.remove_object(self.obj_info["name"])
+
+    def detach_object_from_robot(self):
+        self.robot_col_mngr.remove_object(
+            self.obj_info["name"]
+        )
+        self.object_col_mngr.add_object(
+            self.obj_info["name"], 
+            gtype=self.obj_info["gtype"], 
+            gparam=self.obj_info["gparam"], 
+            transform=self.result_object_pose)
+
+    @abstractclassmethod
+    def get_path_in_joinst_space(self):
+        """
+        write planner algorithm you want 
+        """
+        raise NotImplementedError
+
+    @abstractclassmethod
+    def _get_linear_path(self, init_pose, goal_pose):
+        raise NotImplementedError
+
+    def _setup_collision_manager(
+        self, 
+        robot_col_manager,
+        object_col_manager,
+        is_attached,
+        current_obj_info,
+        result_obj_info,
+        T_between_gripper_and_obj
+    ):
+        self.robot_col_mngr = robot_col_manager
+        self.object_col_mngr = object_col_manager
+        self.is_attached = is_attached
+
+        if current_obj_info is not None and result_obj_info is not None:
+            self.obj_info = current_obj_info
+            self.T_between_gripper_and_obj = T_between_gripper_and_obj
+            self.result_object_pose = result_obj_info["transform"]
+
+            if not self.is_attached:
+                self.object_col_mngr.set_transform(self.obj_info["name"], self.obj_info["transform"])    
+
+            self.robot_col_mngr.show_collision_info(name="Robot")
+            self.object_col_mngr.show_collision_info(name="Object")
+
     @staticmethod
     def _change_types(datas):
         """
@@ -70,6 +119,17 @@ class Planner(metaclass=ABCMeta):
         """
         return np.all([q_in >= self.q_limits_lower, q_in <= self.q_limits_upper])
 
+    def _check_robot_col_mngr(self, robot_col_manager):
+        if robot_col_manager is None:
+            return False
+        
+        is_self_collision = robot_col_manager.in_collision_internal()
+        
+        if is_self_collision:
+            raise CollisionError("Conflict confirmed. Check the joint settings again")
+        
+        return True
+
     def _setup_eef_name(self):
         """
         Setup end-effector name
@@ -77,7 +137,7 @@ class Planner(metaclass=ABCMeta):
         if self.arm is not None:
             self.eef_name = self.robot.eef_name[self.arm]
 
-    def _collision_free(self, new_q, is_attached=False):
+    def _collision_free(self, new_q, is_attached=False, visible_name=False):
         """
         Check collision free between robot and objects
 
@@ -89,7 +149,7 @@ class Planner(metaclass=ABCMeta):
             names(set of 2-tup): The set of pairwise collisions. 
         """
  
-        if self.self_c_manager is None:
+        if self.robot_col_mngr is None:
             return True
 
         transformations = self._get_transformations(new_q)
@@ -97,32 +157,31 @@ class Planner(metaclass=ABCMeta):
         if is_attached:
             grasp_pose = transformations[self.robot.eef_name].h_mat
             obj_pose = np.dot(grasp_pose, self.T_between_gripper_and_obj)
-            self.self_c_manager.set_transform(self.obj_info["name"], obj_pose)
+            self.robot_col_mngr.set_transform(self.obj_info["name"], obj_pose)
         
         for link, transformations in transformations.items():
-            if link in self.self_c_manager._objs:
+            if link in self.robot_col_mngr._objs:
                 transform = transformations.h_mat
-                A2B = np.dot(transform, self.robot.links[link].visual.offset.h_mat)
-                self.self_c_manager.set_transform(name=link, transform=A2B)
-
-        is_self_collision = self.self_c_manager.in_collision_internal(return_names=False, return_data=False)
-        is_object_collision = self.self_c_manager.in_collision_other(other_manager=self.object_c_manager, return_names=False)  
+                if self.robot_col_mngr.geom == "visual":
+                    A2B = np.dot(transform, self.robot.links[link].visual.offset.h_mat)
+                else:
+                    A2B = np.dot(transform, self.robot.links[link].collision.offset.h_mat)
+                # print(link, A2B)
+                self.robot_col_mngr.set_transform(name=link, transform=A2B)
+        
+        is_self_collision = self.robot_col_mngr.in_collision_internal(return_names=False, return_data=False)
+        
+        if visible_name:
+            is_object_collision, col_name = self.robot_col_mngr.in_collision_other(other_manager=self.object_col_mngr, return_names=visible_name)  
+            if is_self_collision or is_object_collision:
+                return False, col_name
+            return True, col_name
 
+        is_object_collision = self.robot_col_mngr.in_collision_other(other_manager=self.object_col_mngr, return_names=False)  
         if is_self_collision or is_object_collision:
             return False
         return True
 
-    @abstractclassmethod
-    def get_path_in_joinst_space(self):
-        """
-        write planner algorithm you want 
-        """
-        raise NotImplementedError
-
-    @abstractclassmethod
-    def _get_linear_path(self, init_pose, goal_pose):
-        raise NotImplementedError
-
     def _get_transformations(self, q_in):
         """
         Get transformations corresponding to q_in
