@@ -20,9 +20,10 @@ class ActivityBase:
     ):
         self.robot = robot
         self.robot_c_manager = robot_col_manager
-        self.objects_c_manager = objects_col_manager
+        self.object_c_manager = objects_col_manager
         self.gripper_c_manager = CollisionManager()
         self.mesh_path = mesh_path
+
         self.gripper_names = gripper_configures.get("gripper_names", None)
         self.gripper_names.insert(0, self.robot.eef_name)
         self.gripper_max_width = gripper_configures.get("gripper_max_width", 0.0)
@@ -69,23 +70,32 @@ class ActivityBase:
     def collision_free(self, transformations, only_gripper=False) -> bool:
         for link, transform in transformations.items():
             if only_gripper:
-                if self.robot.links[link].collision.gtype == "mesh":
-                    A2B = np.dot(transform, self.robot.links[link].collision.offset.h_mat)
-                    self.gripper_c_manager.set_transform(link, A2B)
+                if self.robot_c_manager.geom == "visual":
+                    if self.robot.links[link].visual.gtype == "mesh":
+                        A2B = np.dot(transform, self.robot.links[link].visual.offset.h_mat)
+                        self.gripper_c_manager.set_transform(link, A2B)
+                else:
+                    if self.robot.links[link].collision.gtype == "mesh":
+                        A2B = np.dot(transform, self.robot.links[link].collision.offset.h_mat)
+                        self.gripper_c_manager.set_transform(link, A2B)
             else:
-                for link, transform in transformations.items():
-                    if link in self.robot_c_manager._objs:
+                if link in self.robot_c_manager._objs:
+                    if self.robot_c_manager.geom == "visual":
+                        A2B = np.dot(transform.h_mat, self.robot.links[link].visual.offset.h_mat)
+                        self.robot_c_manager.set_transform(name=link, transform=A2B)
+                    else:
                         A2B = np.dot(transform.h_mat, self.robot.links[link].collision.offset.h_mat)
+                    # print(link, A2B)
                         self.robot_c_manager.set_transform(name=link, transform=A2B)
         
         if only_gripper:
-            is_object_collision = self.gripper_c_manager.in_collision_other(other_manager=self.objects_c_manager)
+            is_object_collision = self.gripper_c_manager.in_collision_other(other_manager=self.object_c_manager)
             if is_object_collision:
                 return False
             return True
         else:
-            is_self_collision = self.robot_c_manager.in_collision_internal()
-            is_object_collision = self.robot_c_manager.in_collision_other(other_manager=self.objects_c_manager)
+            is_self_collision = self.robot_c_manager.in_collision_internal(return_names=False)
+            is_object_collision = self.robot_c_manager.in_collision_other(other_manager=self.object_c_manager, return_names=False)
             if is_self_collision or is_object_collision:
                 return False
             return True
