@@ -39,10 +39,9 @@ class GraspManager(ActivityBase):
         self.retreat_distance = retreat_distance
         self.release_distance = release_distance
         self.tcp_pose = np.eye(4)
-        self.result_obj_pose = np.eye(4)
+        self.post_release_pose = np.eye(4)
         self.contact_points = None
-        self.result_object_c_manager = []
-        self.result_object_c_manager.append(self.objects_c_manager)
+        
         self.obj_info = None
         self.has_obj = False
 
@@ -60,7 +59,7 @@ class GraspManager(ActivityBase):
         if obj_info:
             self.has_obj = True
             self.obj_info = obj_info
-            obj_mesh = obj_info["gtype"]
+            obj_mesh = obj_info["gparam"]
             obj_pose = obj_info["transform"]
 
         grasp_pose = self.get_grasp_pose(obj_mesh, obj_pose, limit_angle, num_grasp, n_trials)    
@@ -124,45 +123,39 @@ class GraspManager(ActivityBase):
             if qpos is None:
                 continue
 
-            transforms = self.robot.forward_kin(np.array(qpos))
-            goal_pose = transforms[self.robot.eef_name].h_mat
+            grasp_transforms = self.robot.forward_kin(np.array(qpos))
+            goal_eef_pose = grasp_transforms[self.robot.eef_name].h_mat
  
-            if self._check_ik_solution(grasp_pose, goal_pose) and self.collision_free(transforms):
+            if self._check_ik_solution(grasp_pose, goal_eef_pose) and self.collision_free(grasp_transforms):
                 pre_grasp_pose = self.get_pre_grasp_pose(grasp_pose)
-                pre_qpos = self._compute_inverse_kinematics(pre_grasp_pose)
-                pre_transforms = self.robot.forward_kin(np.array(pre_qpos))
-                pre_goal_pose = pre_transforms[self.robot.eef_name].h_mat
-
+                pre_transforms, pre_goal_pose = self._get_goal_pose(pre_grasp_pose)
+        
                 if self._check_ik_solution(pre_grasp_pose, pre_goal_pose) and self.collision_free(pre_transforms):
                     self.pre_grasp_pose = pre_grasp_pose
                     
                     post_grasp_pose = self.get_post_grasp_pose(grasp_pose)
-                    post_qpos = self._compute_inverse_kinematics(post_grasp_pose)
-                    post_transforms = self.robot.forward_kin(np.array(post_qpos))
-                    post_goal_pose = post_transforms[self.robot.eef_name].h_mat
-                    
+                    post_transforms, post_goal_pose = self._get_goal_pose(post_grasp_pose)
+
                     if self.has_obj:
-                        # Attach gripper to object
+                        self.obj_pre_grasp_pose = self.obj_info["transform"]
+                        self.obj_grasp_pose = self.obj_info["transform"]
+
                         self.T_between_gripper_and_obj = get_relative_transform(grasp_pose, self.obj_info["transform"])
                         obj_post_grasp_pose = np.dot(post_grasp_pose, self.T_between_gripper_and_obj)
-
-                        self.robot_c_manager.add_object(
-                            self.obj_info["name"], 
-                            gtype="mesh", gparam=self.obj_info["gtype"], transform=obj_post_grasp_pose)
-                        self.obj_grasp_pose = self.obj_info["transform"]
                         self.obj_post_grasp_pose = obj_post_grasp_pose
-                    
+                        self._attach_gripper2object(obj_post_grasp_pose)
+
                     if self._check_ik_solution(post_grasp_pose, post_goal_pose) and self.collision_free(post_transforms):
                         self.post_grasp_pose = post_grasp_pose
                         is_success_filtered = True
                         break
 
         if not is_success_filtered:
-            logger.error(f"Failed to filter grasp poses")
+            logger.error(f"Failed to filter Grasp poses")
             return None
 
         # self.robot_c_manager.remove_object(self.obj_info["name"])
-        logger.info(f"Success to get grasp pose.\n")
+        logger.info(f"Success to get Grasp pose.\n")
 
         return grasp_pose
 
@@ -206,11 +199,11 @@ class GraspManager(ActivityBase):
         waypoints = OrderedDict()
 
         if obj_info_on_sup:
-            obj_mesh_on_sup = obj_info_on_sup["gtype"]
+            obj_mesh_on_sup = obj_info_on_sup["gparam"]
             obj_pose_on_sup = obj_info_on_sup["transform"]
 
         if obj_info_for_sup:
-            obj_mesh_for_sup = obj_info_for_sup["gtype"]
+            obj_mesh_for_sup = obj_info_for_sup["gparam"]
             obj_pose_for_sup = obj_info_for_sup["transform"]
 
         release_pose = self.get_release_pose(
@@ -256,10 +249,10 @@ class GraspManager(ActivityBase):
         pre_release_pose[:3, 3] = release_pose[:3, 3] + np.array([0, 0, self.retreat_distance])
         return pre_release_pose
 
-    def get_post_release_pose(self, grasp_pose):
+    def get_post_release_pose(self, release_pose):
         post_release_pose = np.eye(4)
-        post_release_pose[:3, :3] = grasp_pose[:3, :3] 
-        post_release_pose[:3, 3] = grasp_pose[:3, 3] - self.retreat_distance * grasp_pose[:3,2]
+        post_release_pose[:3, :3] = release_pose[:3, :3] 
+        post_release_pose[:3, 3] = release_pose[:3, 3] - self.retreat_distance * release_pose[:3,2]
         return post_release_pose
 
     def generate_supports(
@@ -320,7 +313,6 @@ class GraspManager(ActivityBase):
             obj_pose_transformed_for_sup[:3, 3] = obj_pose_for_sup[:3, 3]
 
             point_transformed = np.dot(point_for_sup - obj_pose_for_sup[:3, 3], R_mat) + obj_pose_for_sup[:3, 3]
-            # normal_transformed = np.dot(normal_for_sup, R_mat)
 
             result_obj_pose = np.eye(4)
             result_obj_pose[:3, :3] = obj_pose_transformed_for_sup[:3, :3]
@@ -343,44 +335,40 @@ class GraspManager(ActivityBase):
 
             if self.has_obj:
                 self.robot_c_manager.set_transform(self.obj_info["name"], result_obj_pose)
-                
+
             if self._check_ik_solution(release_pose, goal_pose) and self.collision_free(transforms):
                 pre_release_pose = self.get_pre_release_pose(release_pose)
-                pre_qpos = self._compute_inverse_kinematics(pre_release_pose)
-                pre_transforms = self.robot.forward_kin(np.array(pre_qpos))
-                pre_goal_pose = pre_transforms[self.robot.eef_name].h_mat
+                pre_release_transforms, pre_release_goal_pose = self._get_goal_pose(pre_release_pose)
 
                 if self.has_obj:
                     obj_pre_release_pose = np.dot(pre_release_pose, self.T_between_gripper_and_obj)
                     self.robot_c_manager.set_transform(self.obj_info["name"], obj_pre_release_pose)
                     self.obj_pre_release_pose = obj_pre_release_pose
 
-                if self._check_ik_solution(pre_release_pose, pre_goal_pose) and self.collision_free(pre_transforms):
+                if self._check_ik_solution(pre_release_pose, pre_release_goal_pose) and self.collision_free(pre_release_transforms):
                     self.pre_release_pose = pre_release_pose
                     
                     post_release_pose = self.get_post_release_pose(release_pose)
-                    post_qpos = self._compute_inverse_kinematics(post_release_pose)
-                    post_transforms = self.robot.forward_kin(np.array(post_qpos))
-                    post_goal_pose = post_transforms[self.robot.eef_name].h_mat
+                    post_release_transforms, post_release_goal_pose = self._get_goal_pose(post_release_pose)
 
                     if self.has_obj:
-                        self.objects_c_manager.set_transform(self.obj_info["name"], result_obj_pose)
+                        self.object_c_manager.set_transform(self.obj_info["name"], result_obj_pose)
 
-                    if self._check_ik_solution(post_release_pose, post_goal_pose) and self.collision_free(post_transforms):
+                    if self._check_ik_solution(post_release_pose, post_release_goal_pose) and self.collision_free(post_release_transforms):
                         self.post_release_pose = post_release_pose
-                        self.result_obj_pose = result_obj_pose
+                        self.obj_release_pose = result_obj_pose
+                        self.obj_post_release_pose = result_obj_pose
                         is_success_filtered = True
                         break
 
         if not is_success_filtered:
-            logger.error(f"Failed to filter release poses")
+            logger.error(f"Failed to filter Release poses")
             return None
         
         if self.has_obj:
             self.robot_c_manager.remove_object(self.obj_info["name"])
-            self.result_object_c_manager.append(self.objects_c_manager)
 
-        logger.info(f"Success to get release pose.\n")
+        logger.info(f"Success to get Release pose.\n")
         return release_pose
 
     def generate_points_on_support(
@@ -483,6 +471,17 @@ class GraspManager(ActivityBase):
             return True
         return False
 
+    def _get_goal_pose(self, pose):
+        qpos = self._compute_inverse_kinematics(pose)
+        transforms = self.robot.forward_kin(np.array(qpos))
+        goal_pose = transforms[self.robot.eef_name].h_mat
+        return transforms, goal_pose
+
+    def _attach_gripper2object(self, obj_post_grasp_pose):
+        self.robot_c_manager.add_object(
+            self.obj_info["name"], 
+            gtype=self.obj_info["gtype"], gparam=self.obj_info["gparam"], transform=obj_post_grasp_pose)
+
     def _check_support(self, obj_pose):
         obj_mesh = deepcopy(self.obj_mesh_for_sup)
         obj_mesh.apply_transform(obj_pose)
